@@ -1,5 +1,6 @@
 #!/usr/bin/python
 
+import os
 import sys
 import logging
 
@@ -11,8 +12,16 @@ import constants
 import dc_glade
 
 
+try:
+	os.makedirs(constants._data_path_)
+except OSError, e:
+	if e.errno != 17:
+		raise
+
 userLogPath = "%s/dialcentral.log" % constants._data_path_
 logging.basicConfig(level=logging.DEBUG, filename=userLogPath)
+logging.info("Dialcentral %s-%s" % (constants.__version__, constants.__build__))
+
 try:
 	dc_glade.run_dialpad()
 finally:
